import testpack.Car;
import java.sql.*;

/*
 This class demonstrates how to use custom Java objects (classes)
 in StelsEngine driver.
*/

public class ObjectsTest {
  public static void main(String[] args) {
    try {
      // load the driver into memory
      Class.forName("jstels.jdbc.engine.EngineDriver");

      // create a connection
      Connection conn = DriverManager.getConnection("jdbc:jstels:engine");

      // create a Statement instance to execute the query with
      Statement stmt = conn.createStatement();

      // create a table that contains object data type
      stmt.execute("CREATE TABLE cars (id INTEGER, owner STRING, car \"testpack.Car\")");

      // create a PreparedStatement instance to insert values
      PreparedStatement pst = conn.prepareStatement(
          "INSERT INTO cars(id,owner,car) values(?,?,?)");
      pst.setInt(1, 1);
      pst.setObject(2, "John Smith");
      pst.setObject(3, new Car("Dodge Viper", 177));
      pst.execute();

      pst.setInt(1, 2);
      pst.setObject(2, "Mary Jones");
      pst.setObject(3, new Car("Porsche 964", 162));
      pst.execute();

      pst.setInt(1, 3);
      pst.setObject(2, "Dan Roberts");
      pst.setObject(3, new Car("Ferrari F430", 196));
      pst.execute();

      // execute a query
      ResultSet rs = stmt.executeQuery(
          "SELECT id, owner, car, car->getName(),car->maxSpeed FROM cars");

      while (rs.next()) {
        for (int j = 1; j <= rs.getMetaData().getColumnCount(); j++) {
          System.out.print(rs.getObject(j) + "\t");
        }
        System.out.println();
      }

    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }
}